@@ -1,10 +1,9 @@
 r"""This package contains the implementation of a lot of utilities used in the
 other packages."""
 
-__all__ = ["AssetManager", "get_available_devices", "manual_seed", "move_to_device", "to_tuple"]
+__all__ = ["get_available_devices", "manual_seed", "move_to_device", "to_tuple"]
 
 
-from gravitorch.utils.asset_manager import AssetManager
 from gravitorch.utils.seed import manual_seed
 from gravitorch.utils.sequence import to_tuple
 from gravitorch.utils.torch_device import get_available_devices, move_to_device
